@@ -45,3 +45,9 @@ class AlarmDescriptionExtensionConflict(Exception):
 
 class LoaderRegistrationError(Exception):
     title = "Loader Registration conflict"
+
+class MissingSNSTopics(Exception):
+    title = "Missing SNS Topic"
+
+class InvalidSubType(Exception):
+    title = "The sub_type for the object is invalid"
\ No newline at end of file
