@@ -26,6 +26,9 @@ class NetworkEnvironment(Named, Deployable, dict):
     def environments(self):
         return self
 
+    def resolve_ref(self, ref):
+        return self
+
 
 @implementer(schemas.IEnvironment)
 class Environment(Named, dict):
@@ -103,16 +106,20 @@ class Network(Named, Deployable, dict):
     def resolve_ref(self, ref):
         if ref.resource_ref == 'aws_account':
             return self.aws_account
-        return None
+        elif ref.resource_ref == 'availability_zones':
+            return self.availability_zones
+        return self
 
 @implementer(schemas.IVPCPeeringRoute)
 class VPCPeeringRoute(Parent):
-    segment = FieldProperty(schemas.IVPCPeeringRoute["segment"])
+    local_segment = FieldProperty(schemas.IVPCPeeringRoute["local_segment"])
+    remote_segment = FieldProperty(schemas.IVPCPeeringRoute["remote_segment"])
     cidr = FieldProperty(schemas.IVPCPeeringRoute["cidr"])
 
 @implementer(schemas.IVPCPeering)
 class VPCPeering(Named, Deployable):
     "VPC Peering"
+    peer_type = FieldProperty(schemas.IVPCPeering["peer_type"])
     peer_role_name = FieldProperty(schemas.IVPCPeering["peer_role_name"])
     peer_vpcid = FieldProperty(schemas.IVPCPeering["peer_vpcid"])
     peer_account_id = FieldProperty(schemas.IVPCPeering["peer_account_id"])
@@ -242,6 +249,7 @@ class SecurityGroupRule():
 @implementer(schemas.IIngressRule)
 class IngressRule(Parent, SecurityGroupRule):
     source_security_group = FieldProperty(schemas.IIngressRule["source_security_group"])
+    source_security_group_owner = FieldProperty(schemas.IIngressRule["source_security_group_owner"])
 
 @implementer(schemas.IEgressRule)
 class EgressRule(Parent, SecurityGroupRule):
@@ -258,8 +266,8 @@ class Segment(Named, Deployable):
     az6_cidr = FieldProperty(schemas.ISegment["az6_cidr"])
 
     def resolve_ref(self, ref):
-        if ref.resource_ref == 'az1_cidr':
-            return self.az1_cidr
+        if ref.parts[-1].endswith('_cidr'):
+            return getattr(self, ref.parts[-1])
         else:
             stack = self.resolve_ref_obj.resolve_ref(ref)
             if stack == None:
@@ -273,6 +281,7 @@ class VPCEndpoint(Named, Deployable):
     service = FieldProperty(schemas.IVPCEndpoint["service"])
     segments = FieldProperty(schemas.IVPCEndpoint["segments"])
     security_group = FieldProperty(schemas.IVPCEndpoint["security_group"])
+    availability_zone = FieldProperty(schemas.IVPCEndpoint["availability_zone"])
 
     def resolve_ref(self, ref):
         if ref.resource_ref == 'service':
